@@ -151,7 +151,7 @@ class Account(ABC):
         return transfer
 
     def intra_account_transfer(self, to_account: Union[CashAccount | ReserveAccount], receiving_amount: Decimal) -> IntraAccountTransfer:
-        intra_account_transfer: IntraAccountTransfer = IntraAccountTransfer.execute(api_key, receiving_amount, self, to_account, self.user_profile.type)    # type: ignore[arg-type]
+        intra_account_transfer: IntraAccountTransfer = IntraAccountTransfer.execute(self.api_key, receiving_amount, self, to_account, self.user_profile.type)    # type: ignore[arg-type]
         if intra_account_transfer.is_successful:
             if isinstance(self, CashAccount):
                 self.balance = Account.get_by_profile_type_and_currency(self.api_key, self.user_profile.type, self.currency).balance
